@@ -28,7 +28,7 @@ from os.path import expanduser, expandvars, join
 import pytz
 import xdg
 from tzlocal import get_localzone
-from configobj.validate import VdtValueError
+from validate import VdtValueError
 
 from ..khalendar.vdir import CollectionNotFoundError, Vdir
 from ..parse_datetime import guesstimedeltafstr
